# Overview

These performance benchmarks serve two purposes:
1. Quantify the impact of PRs that are intended to improve performance, and
2. Measure trends over time to identify/prevent performance regressions.

Please refer to the [contributing performance tests documentation](https://docs.greatexpectations.io/docs/contributing/contributing_test#performance) for info on running and using these tests.
